@@ -30,9 +30,20 @@
 #define ACPI_FILE_BATTERY_STATE "state"
 #define ACPI_FILE_BATTERY_INFO  "info"
 #define ACPI_FILE_FAN           "state"
-
 #define ACPI_INFO               "info"
 
+#define SYS_PATH "/sys/class/"
+#define SYS_POWER_MODEL_NAME "model_name"
+#define SYS_DIR_THERMAL "thermal"
+#define SYS_FILE_THERMAL "temp"
+#define SYS_DIR_POWER "power_supply"
+#define SYS_FILE_ENERGY "energy_now"
+#define SYS_FILE_ENERGY_MIN "alarm"
+#define SYS_FILE_ENERGY_MAX "energy_full"
+#define SYS_FILE_POWER "power_now"
+#define SYS_FILE_VOLTAGE "voltage_now"
+#define SYS_FILE_VOLTAGE_MIN "voltage_min_design"
+
 /* Gtk/Glib includes */
 #include <glib.h>
 
@@ -84,6 +95,15 @@ double get_fan_zone_value (gchar *str_zonename);
 void get_battery_max_value (gchar *str_filename, t_chipfeature *ptr_chipfeature);
 
 
+/**
+ * Read a double value from status file for battery power.
+ * When status is on, result is 1.0; else it is 0.0.
+ * @param str_zonename: file to read information from, e.g. state.
+ * @return valued from any line starting with "status:", converted to 1 or 0
+ */
+double get_power_zone_value (gchar *str_zonename);
+
+
 /**
  * Read information from the thermal zone.
  * @param ptr_chip: Pointer to already allocated chip, where values can be added.
@@ -108,6 +128,14 @@ gint read_battery_zone (t_chip *ptr_chip);
 gint read_fan_zone (t_chip *ptr_chip);
 
 
+/**
+ * Read information from the fan zone.
+ * @param ptr_chip: Pointer to already allocated chip, where values can be added.
+ * @return 0 on success
+ */
+gint read_power_zone (t_chip *ptr_chip);
+
+
 /**
  * Returns the ACPI version number from /proc/acpi/info file.
  * @return versionnumber as string!
