@@ -29,6 +29,18 @@ G_DECLARE_FINAL_TYPE (GtkSensorsTacho, gtk_sensorstacho, GTK, SENSORSTACHO, GtkD
 
 typedef struct _GtkSensorsTacho GtkSensorsTacho;
 
+/**
+ * Enumeration of possible style for sensors tacho.
+ */
+typedef enum _SensorsTachoStyle {
+    /** temperatures, ranging from green over yellow to red */
+    style_MinGYR = 0,
+    /** voltage and power, from yellow over green to blue */
+    style_MediumYGB = 1,
+    /** fill level, mostly used for energy from red ove ryellow to green */
+    style_MaxRYG = 2
+} SensorsTachoStyle;
+
 /**
  * pseudo widget for drawing a tacho
  */
@@ -48,6 +60,9 @@ struct _GtkSensorsTacho {
     /** size of a side of the surrounding square area */
     guint size;
 
+    /** color style of tacho */
+    SensorsTachoStyle style;
+
     /** orientation, used for vertical bars */
     GtkOrientation orientation;
 };
@@ -63,9 +78,10 @@ void gtk_sensorstacho_set_value (GtkSensorsTacho *ptr_sensorstacho, gdouble valu
  * create a new sensorstacho with orientation and initial size
  * @param orientation: orientation of the tacho
  * @param size: initial size of the tacho object
+ * @param style: gradient style of the tacho object
  * @return allocated widget
  */
-GtkWidget * gtk_sensorstacho_new(GtkOrientation orientation, guint size);
+GtkWidget * gtk_sensorstacho_new(GtkOrientation orientation, guint size, SensorsTachoStyle style);
 
 /**
  * set the text to be drawn. if NULL, no text is drawn.
@@ -108,6 +124,24 @@ void gtk_sensorstacho_set_size(GtkSensorsTacho *ptr_sensorstacho, guint size);
  */
 extern gchar *font;
 
+
+#define MAX_HUE 0.8
+#define ALPHA_CHANNEL_VALUE 0.8
+
+/**
+ * directly exhibited internal value describing the desired hue value for the
+ * tacho elements.
+ * TODO: Introduce getter/setter functions
+ */
+extern gfloat val_colorvalue;
+
+/**
+ * directly exhibited internal value describing the desired alpha value for the
+ * tacho elements.
+ * TODO: Introduce getter/setter functions
+ */
+extern gfloat val_alpha;
+
 G_END_DECLS
 
 #endif /* __TACHO_H */
