@@ -111,7 +111,7 @@ read_thermal_zone (t_chip *ptr_chip)
     TRACE ("enters read_thermal_zone");
 
 #ifdef HAVE_SYSFS_ACPI
-    if ((chdir ("/sys/class/") == 0) && (chdir ("thermal/") == 0))
+    if ((chdir (SYS_PATH) == 0) && (chdir (SYS_DIR_THERMAL) == 0))
 #else
     if ((chdir (ACPI_PATH) == 0) && (chdir (ACPI_DIR_THERMAL) == 0))
 #endif
@@ -128,7 +128,7 @@ read_thermal_zone (t_chip *ptr_chip)
                     continue;
 
     #ifdef HAVE_SYSFS_ACPI
-                str_filename = g_strdup_printf ("/sys/class/thermal/%s/temp", ptr_dirent->d_name);
+                str_filename = g_strdup_printf ("/%s/%s/%s/%s", SYS_PATH, SYS_DIR_THERMAL, ptr_dirent->d_name, SYS_FILE_THERMAL);
     #else
                 str_filename = g_strdup_printf ("%s/%s/%s/%s", ACPI_PATH,
                                             ACPI_DIR_THERMAL, ptr_dirent->d_name,
@@ -254,7 +254,7 @@ get_battery_zone_value (gchar *str_zone)
     TRACE ("enters get_battery_zone_value for %s", str_zone);
 
 #ifdef HAVE_SYSFS_ACPI
-    str_filename = g_strdup_printf ("/sys/class/power_supply/%s/energy_now", str_zone);
+    str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, str_zone, SYS_FILE_ENERGY);
 #else
     str_filename = g_strdup_printf ("%s/%s/%s/%s", ACPI_PATH, ACPI_DIR_BATTERY,
                                 str_zone, ACPI_FILE_BATTERY_STATE);
@@ -309,7 +309,7 @@ read_battery_zone (t_chip *ptr_chip)
     TRACE ("enters read_battery_zone");
 
 #ifdef HAVE_SYSFS_ACPI
-    if ((chdir ("/sys/class") == 0) && (chdir ("power_supply") == 0)) {
+    if ((chdir (SYS_PATH) == 0) && (chdir (SYS_DIR_POWER) == 0)) {
 #else
     if ((chdir (ACPI_PATH) == 0) && (chdir (ACPI_DIR_BATTERY) == 0)) {
 #endif
@@ -321,7 +321,7 @@ read_battery_zone (t_chip *ptr_chip)
             { /* have a battery subdirectory */
 
 #ifdef HAVE_SYSFS_ACPI
-                str_filename = g_strdup_printf ("/sys/class/power_supply/%s/model_name", ptr_dirent->d_name);
+                str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, ptr_dirent->d_name, SYS_POWER_MODEL_NAME);
 #else
                 str_filename = g_strdup_printf ("%s/%s/%s/%s", ACPI_PATH,
                                             ACPI_DIR_BATTERY, ptr_dirent->d_name,
@@ -356,7 +356,7 @@ read_battery_zone (t_chip *ptr_chip)
                     fclose (ptr_file);
                 }
                 g_free (str_filename);
-                str_filename = g_strdup_printf ("/sys/class/power_supply/%s/energy_now", ptr_dirent->d_name);
+                str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, ptr_dirent->d_name, SYS_FILE_ENERGY);
                 ptr_file = fopen (str_filename, "r");
                 if (ptr_file) {
 
@@ -369,7 +369,7 @@ read_battery_zone (t_chip *ptr_chip)
                     fclose (ptr_file);
                 }
                 g_free (str_filename);
-                str_filename = g_strdup_printf ("/sys/class/power_supply/%s/alarm", ptr_dirent->d_name);
+                str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, ptr_dirent->d_name, SYS_FILE_ENERGY_MIN);
                 ptr_file = fopen (str_filename, "r");
                 if (ptr_file) {
                     if (fgets (buffer, 1024, ptr_file)!=NULL)
@@ -449,7 +449,7 @@ get_battery_max_value (gchar *str_filename, t_chipfeature *ptr_chipfeature)
     TRACE ("enters get_battery_max_value");
 
 #ifdef HAVE_SYSFS_ACPI
-    str_pathtofile = g_strdup_printf ("/sys/class/power_supply/%s/energy_full", str_filename);
+    str_pathtofile = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, str_filename, SYS_FILE_ENERGY_MAX);
 #else
     str_pathtofile = g_strdup_printf ("%s/%s/%s/%s", ACPI_PATH,
                                             ACPI_DIR_BATTERY, str_filename,
@@ -562,6 +562,110 @@ read_fan_zone (t_chip *ptr_chip)
 }
 
 
+/* -------------------------------------------------------------------------- */
+gdouble
+get_power_zone_value (gchar *str_zone)
+{
+    gdouble res_value = 0.0;
+
+    FILE *ptr_file;
+    gchar buffer [1024], *str_filename;
+
+    g_return_val_if_fail(str_zone!=NULL, res_value);
+
+    TRACE ("enters get_power_zone_value for %s", str_zone);
+
+    str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, str_zone, SYS_FILE_POWER);
+
+    DBG("str_filename=%s\n", str_filename);
+    ptr_file = fopen (str_filename, "r");
+    if (ptr_file) {
+        if (fgets (buffer, 1024, ptr_file)!=NULL)
+        {
+            cut_newline (buffer);
+            res_value = strtod (buffer, NULL) / 1000000.0;
+        }
+        fclose (ptr_file);
+    }
+
+    g_free (str_filename);
+
+    return res_value;
+}
+
+
+/* -------------------------------------------------------------------------- */
+gint
+read_power_zone (t_chip *ptr_chip)
+{
+    gint res_value = -1;
+
+    DIR *ptr_dir;
+    FILE *ptr_file;
+    gchar *str_filename;
+    struct dirent *ptr_dirent;
+    t_chipfeature *ptr_chipfeature = NULL;
+
+    g_return_val_if_fail(ptr_chip!=NULL, res_value);
+
+    TRACE ("enters read_power_zone");
+
+    if ((chdir (SYS_PATH) == 0) && (chdir (SYS_DIR_POWER) == 0)) {
+        ptr_dir = opendir (".");
+
+        while (ptr_dir && (ptr_dirent = readdir (ptr_dir)))
+        {
+            if (strncmp(ptr_dirent->d_name, "BAT", 3)==0)
+            { /* have a battery subdirectory */
+
+                str_filename = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_POWER, ptr_dirent->d_name, SYS_FILE_POWER);
+                ptr_file = fopen (str_filename, "r");
+                if (ptr_file) {
+
+                    ptr_chipfeature = g_new0 (t_chipfeature, 1);
+                    g_return_val_if_fail(ptr_chipfeature != NULL, -1);
+
+                    ptr_chipfeature->color = g_strdup("#00B0B0");
+                    ptr_chipfeature->address = ptr_chip->chip_features->len;
+                    ptr_chipfeature->devicename = g_strdup(ptr_dirent->d_name);
+                    // You might want to format this with a hyphen and without spacing, or with a dash; the result might be BAT1–Power or whatever fits your language most. Spaces allow line breaks over the tachometers.
+                    ptr_chipfeature->name = g_strdup_printf (_("%s - %s"), ptr_dirent->d_name, _("Power"));
+                    ptr_chipfeature->formatted_value = NULL;
+                    ptr_chipfeature->raw_value = get_power_zone_value(ptr_dirent->d_name);
+                    ptr_chipfeature->valid = TRUE;
+                    ptr_chipfeature->min_value = 0.0;
+                    ptr_chipfeature->max_value = 60.0; // a T440s charges with roughly 25 Watts
+                    ptr_chipfeature->class = POWER;
+
+                    g_ptr_array_add (ptr_chip->chip_features, ptr_chipfeature);
+
+                    ptr_chip->num_features++; /* FIXME: actually I am just the same as
+                    chip->chip_features->len */
+
+                    fclose (ptr_file);
+                }
+                g_free (str_filename);
+
+            }
+
+            res_value = 0;
+        }
+
+        if (ptr_dir)
+            closedir (ptr_dir);
+
+        TRACE ("leaves read_power_zone");
+    }
+    else
+    {
+        TRACE ("leaves read_power_zone");
+        res_value = -2;
+    }
+
+    return res_value;
+}
+
+
 /* -------------------------------------------------------------------------- */
 gint
 initialize_ACPI (GPtrArray *arr_ptr_chips)
@@ -600,6 +704,7 @@ initialize_ACPI (GPtrArray *arr_ptr_chips)
     read_battery_zone (ptr_chip);
     read_thermal_zone (ptr_chip);
     read_fan_zone (ptr_chip);
+    read_power_zone(ptr_chip);
 
     g_ptr_array_add (arr_ptr_chips, ptr_chip);
 
@@ -630,7 +735,7 @@ refresh_acpi (gpointer ptr_chipfeature, gpointer ptr_unused)
     switch (cf->class) {
         case TEMPERATURE:
 #ifdef HAVE_SYSFS_ACPI
-            str_zone = g_strdup_printf ("/sys/class/thermal_zone/%s/temp", cf->devicename);
+            str_zone = g_strdup_printf ("%s/%s/%s/%s", SYS_PATH, SYS_DIR_THERMAL, cf->devicename, SYS_FILE_THERMAL);
             ptr_file = fopen(str_zone, "r");
             if (ptr_file)
             {
@@ -653,6 +758,10 @@ refresh_acpi (gpointer ptr_chipfeature, gpointer ptr_unused)
             cf->raw_value = get_battery_zone_value (cf->devicename);
             break;
 
+        case POWER:
+            cf->raw_value = get_power_zone_value (cf->devicename);
+            break;
+
         case STATE:
             str_filename = g_strdup_printf ("%s/%s/%s/state", ACPI_PATH, ACPI_DIR_FAN, cf->devicename);
 
