@@ -143,6 +143,14 @@ sensors_write_config (XfcePanelPlugin *plugin,t_sensors *ptr_sensors)
             xfce_rc_write_int_entry (ptr_xfcerc, "Preferred_Width", ptr_sensors->preferred_width);
             xfce_rc_write_int_entry (ptr_xfcerc, "Preferred_Height", ptr_sensors->preferred_height);
 
+            str_tmp = g_strdup_printf("%.2f", ptr_sensors->val_tachos_color);
+            xfce_rc_write_entry (ptr_xfcerc, "Tachos_ColorValue", str_tmp);
+            g_free (str_tmp);
+
+            str_tmp = g_strdup_printf("%.2f", ptr_sensors->val_tachos_alpha);
+            xfce_rc_write_entry (ptr_xfcerc, "Tachos_Alpha", str_tmp);
+            g_free (str_tmp);
+
             for (idx_chips=0; idx_chips<ptr_sensors->num_sensorchips; idx_chips++) {
 
                 ptr_chip = (t_chip *) g_ptr_array_index(ptr_sensors->chips, idx_chips);
@@ -167,8 +175,6 @@ sensors_write_config (XfcePanelPlugin *plugin,t_sensors *ptr_sensors)
 
                        xfce_rc_set_group (ptr_xfcerc, str_feature);
 
-                       xfce_rc_write_int_entry (ptr_xfcerc, "Id", get_Id_from_address(idx_chips, idx_features, ptr_sensors));
-
                        /* only use this if no hddtemp sensor */
                        /* or do only use this , if it is an lmsensors device. whatever. */
                        if ( strcmp(ptr_chip->sensorId, _("Hard disks")) != 0 ) /* chip->name? */
@@ -272,6 +278,14 @@ sensors_read_general_config (XfceRc *ptr_xfceresources, t_sensors *ptr_sensors)
         ptr_sensors->preferred_width = xfce_rc_read_int_entry (ptr_xfceresources, "Preferred_Width", 400);
         ptr_sensors->preferred_height = xfce_rc_read_int_entry (ptr_xfceresources, "Preferred_Height", 400);
 
+        if ((str_value = xfce_rc_read_entry (ptr_xfceresources, "Tachos_ColorValue", NULL))
+                && *str_value)
+            ptr_sensors->val_tachos_color = atof (str_value);
+
+        if ((str_value = xfce_rc_read_entry (ptr_xfceresources, "Tachos_Alpha", NULL))
+                && *str_value)
+            ptr_sensors->val_tachos_alpha = atof (str_value);
+
         //num_chips = xfce_rc_read_int_entry (ptr_xfceresources, "Number_Chips", 0);
         /* or could use 1 or the always existent dummy entry */
     }
@@ -319,7 +333,7 @@ sensors_read_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
     gint idx_chip, idx_feature, idx_chiptmp;
     gchar str_rcchip[8], str_feature[20];
     gchar* str_sensorname=NULL;
-    gint num_sensorchip, id, address;
+    gint num_sensorchip;
     t_chip *ptr_chip;
     t_chipfeature *ptr_chipfeature;
 
@@ -382,21 +396,7 @@ sensors_read_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
                     if (xfce_rc_has_group (ptr_xfceresource, str_feature)) {
                         xfce_rc_set_group (ptr_xfceresource, str_feature);
 
-                        address=0;
-
-                        id = (gint) xfce_rc_read_int_entry (ptr_xfceresource, "Id", 0);
-
-                        /* FIXME: compare strings, or also have hddtemp and acpi store numeric str_values */
-
-                        /* assert correctly saved str_file */
-                        if (id >= 0 && strcmp(ptr_chip->sensorId, _("Hard disks")) != 0) { /* chip->name? */
-                            ptr_chipfeature = g_ptr_array_index(ptr_chip->chip_features, id);
-                            address = (gint) xfce_rc_read_int_entry (ptr_xfceresource, "Address", 0);
-                            /* FIXME: it might be necessary to use sensors->addresses here */
-                            if (!ptr_chipfeature || ptr_chipfeature->address != address)
-                                continue;
-                        }
-                        else if ((str_value = xfce_rc_read_entry (ptr_xfceresource, "DeviceName", NULL))
+                        if ((str_value = xfce_rc_read_entry (ptr_xfceresource, "DeviceName", NULL))
                             && *str_value) {
                             if (ptr_chipfeature->devicename)
                                 g_free (ptr_chipfeature->devicename);
