@@ -89,6 +89,7 @@ remove_gsource (guint gsource_id)
     }
 }
 
+#define BAR_SIZE 8
 
 /* -------------------------------------------------------------------------- */
 static void
@@ -98,10 +99,10 @@ sensors_set_levelbar_size (GtkWidget *ptr_levelbar, int siz_panelheight, int pan
     g_return_if_fail (G_IS_OBJECT(ptr_levelbar));
 
     if (panelorientation == XFCE_PANEL_PLUGIN_MODE_HORIZONTAL) {
-        gtk_widget_set_size_request (ptr_levelbar, BORDER+2, siz_panelheight-BORDER);
+        gtk_widget_set_size_request (ptr_levelbar, BAR_SIZE+2, siz_panelheight-BAR_SIZE);
     }
     else {
-        gtk_widget_set_size_request (ptr_levelbar, siz_panelheight-BORDER, BORDER+2);
+        gtk_widget_set_size_request (ptr_levelbar, siz_panelheight-BAR_SIZE, BAR_SIZE+2);
     }
 }
 
@@ -115,16 +116,18 @@ sensors_set_bar_color (t_labelledlevelbar *ptr_labelledlevelbar, double val_perc
 
     gchar str_gtkcssdata[256] = "levelbar block.";
     gchar str_levelbarid[32];
+    //gchar str_section_levelbarid[64];
 
     g_return_if_fail(ptr_labelledlevelbar != NULL);
     ptr_levelbar = ptr_labelledlevelbar->progressbar;
 
     g_return_if_fail (G_IS_OBJECT(ptr_levelbar));
 
-
     g_snprintf(str_levelbarid, 32, "warn-high%lX", (unsigned long int) ptr_levelbar);
 
     g_strlcat(str_gtkcssdata, str_levelbarid, sizeof(str_gtkcssdata));
+    //g_strlcpy(str_section_levelbarid, str_gtkcssdata, sizeof(str_section_levelbarid));
+
     g_strlcat(str_gtkcssdata, " {\n", sizeof(str_gtkcssdata));
 
     if (ptr_sensorsstructure->show_colored_bars) {
@@ -155,6 +158,9 @@ sensors_set_bar_color (t_labelledlevelbar *ptr_labelledlevelbar, double val_perc
 
     gtk_css_provider_load_from_data (GTK_CSS_PROVIDER(ptr_labelledlevelbar->css_provider),
                                    str_gtkcssdata, strlen(str_gtkcssdata), NULL);
+
+    //DBG("unreferencing section '%s'.", str_section_levelbarid);
+    //gtk_css_section_unref(str_section_levelbarid);
 }
 
 
@@ -461,7 +467,7 @@ sensors_add_graphical_display (t_sensors *ptr_sensors)
                 ptr_sensors->panels[idx_sensorchips][idx_feature] = ptr_labelledlevelbar;
 
                 gtk_box_pack_start (GTK_BOX (ptr_sensors->widget_sensors),
-                                    widget_databox, FALSE, FALSE, INNER_BORDER);
+                                    widget_databox, FALSE, FALSE, INNER_BORDER/2);
             }
         }
     }
@@ -491,6 +497,7 @@ sensors_add_tacho_display (t_sensors *ptr_sensors)
     gboolean has_tachos = FALSE;
     GtkWidget *ptr_tacho;
     gchar *str_panellabeltext;
+    SensorsTachoStyle tacho_style;
 
     gint size_panel = ptr_sensors->panel_size;
 
@@ -514,11 +521,26 @@ sensors_add_tacho_display (t_sensors *ptr_sensors)
         for (idx_feature=0; idx_feature < ptr_chip->num_features; idx_feature++) {
             ptr_chipfeature = g_ptr_array_index (ptr_chip->chip_features, idx_feature);
             g_assert (ptr_chipfeature != NULL);
+            tacho_style = style_MinGYR; /* default as has been for 10 years */
 
             if (ptr_chipfeature->show == TRUE) {
                 has_tachos = TRUE;
 
-                ptr_tacho = gtk_sensorstacho_new(ptr_sensors->orientation, size_panel);
+                switch (ptr_chipfeature->class) {
+                    case VOLTAGE:
+                    case POWER:
+                    case CURRENT:
+                    //case TEMPERATURE: // activate for developping only
+                        tacho_style = style_MediumYGB;
+                        break;
+                    case ENERGY:
+                        tacho_style = style_MaxRYG;
+                        break;
+                    default: // tacho_style = style_MinGYR; // already set per default
+                        break;
+                }
+
+                ptr_tacho = gtk_sensorstacho_new(ptr_sensors->orientation, size_panel, tacho_style);
 
                 /* create the label stuff only if needed - saves some memory! */
                 if (ptr_sensors->show_labels == TRUE) {
@@ -657,6 +679,9 @@ sensors_show_tacho_display (t_sensors *ptr_sensors)
     g_return_val_if_fail(ptr_sensors != NULL, FALSE);
 
     if (ptr_sensors->tachos_created == FALSE) {
+        val_colorvalue = ptr_sensors->val_tachos_color;
+        val_alpha = ptr_sensors->val_tachos_alpha;
+
         sensors_add_tacho_display (ptr_sensors);
     }
 
@@ -1017,8 +1042,7 @@ sensors_create_tooltip (gpointer ptr_argument)
                                                     &(ptr_sensors->suppressmessage));
 
                 if (result != 0) {
-                    /* FIXME: either print nothing, or undertake appropriate action,
-                     * or pop up a message box. */
+                    /* output to stdout on command line, not very useful for user, except for tracing problems */
                     g_printf ( _("Sensors Plugin:\n"
                     "Seems like there was a problem reading a sensor feature "
                     "value.\nProper proceeding cannot be guaranteed.\n") );
@@ -1352,8 +1376,10 @@ display_style_changed_text (GtkWidget *widget, t_sensors_dialog *sd)
     gtk_widget_hide(sd->fontSettings_Box);
     gtk_widget_show(sd->font_Box);
     gtk_widget_show(sd->Lines_Box);
-    gtk_widget_show (sd->unit_checkbox);
-    gtk_widget_show (sd->smallspacing_checkbox);
+    gtk_widget_show(sd->unit_checkbox);
+    gtk_widget_show(sd->smallspacing_checkbox);
+    gtk_widget_hide(sd->colorvalue_slider_box);
+    gtk_widget_hide(sd->alpha_slider_box);
 
     sd->sensors->display_values_type = DISPLAY_TEXT;
 
@@ -1380,8 +1406,10 @@ display_style_changed_bars (GtkWidget *widget, t_sensors_dialog *sd)
     gtk_widget_hide(sd->fontSettings_Box);
     gtk_widget_hide(sd->font_Box);
     gtk_widget_hide(sd->Lines_Box);
-    gtk_widget_hide (sd->unit_checkbox);
-    gtk_widget_hide (sd->smallspacing_checkbox);
+    gtk_widget_hide(sd->unit_checkbox);
+    gtk_widget_hide(sd->smallspacing_checkbox);
+    gtk_widget_hide(sd->colorvalue_slider_box);
+    gtk_widget_hide(sd->alpha_slider_box);
 
     sd->sensors->display_values_type = DISPLAY_BARS;
 
@@ -1426,8 +1454,10 @@ display_style_changed_tacho (GtkWidget *widget, t_sensors_dialog *sd)
     gtk_widget_show(sd->fontSettings_Box);
     gtk_widget_hide(sd->font_Box);
     gtk_widget_hide(sd->Lines_Box);
-    gtk_widget_hide (sd->unit_checkbox);
-    gtk_widget_hide (sd->smallspacing_checkbox);
+    gtk_widget_hide(sd->unit_checkbox);
+    gtk_widget_hide(sd->smallspacing_checkbox);
+    gtk_widget_show(sd->colorvalue_slider_box);
+    gtk_widget_show(sd->alpha_slider_box);
 
     sd->sensors->display_values_type = DISPLAY_TACHO;
 
@@ -1911,20 +1941,58 @@ list_cell_toggle_ (GtkCellRendererToggle *cell, gchar *path_str,
 static void
 on_font_set (GtkWidget *widget, gpointer data)
 {
-        t_sensors *sensors;
-        sensors = (t_sensors *) data;
-        g_assert (sensors!=NULL);
+    t_sensors *sensors;
+    sensors = (t_sensors *) data;
+    g_assert (sensors!=NULL);
 
-        if (font)
-            g_free (font);
+    if (font)
+        g_free (font);
 
-        font = g_strdup(gtk_font_button_get_font_name(GTK_FONT_BUTTON(widget)));
+    font = g_strdup(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(widget)));
 
-        if (sensors->display_values_type==DISPLAY_TACHO)
-        {
-            /* refresh the panel content */
-            sensors_update_tacho_panel (sensors);
-        }
+    if (sensors->display_values_type==DISPLAY_TACHO)
+    {
+        /* refresh the panel content */
+        sensors_update_tacho_panel (sensors);
+    }
+}
+
+
+/* -------------------------------------------------------------------------- */
+static void
+tachos_colorvalue_changed_ (GtkWidget *ptr_widget, GtkScrollType type, gdouble value, t_sensors_dialog *ptr_sensorsdialog)
+{
+    t_sensors *sensors;
+    sensors = ptr_sensorsdialog->sensors;
+    g_assert (sensors!=NULL);
+
+    sensors->val_tachos_color = val_colorvalue = value; //gtk_scale_button_get_value(GTK_SCALE_BUTTON(ptr_widget));
+    DBG("new color value is %f.", val_colorvalue);
+
+    if (sensors->display_values_type==DISPLAY_TACHO)
+    {
+        /* refresh the panel content */
+        sensors_update_tacho_panel (sensors);
+    }
+}
+
+
+/* -------------------------------------------------------------------------- */
+static void
+tachos_alpha_changed_ (GtkWidget *ptr_widget, GtkScrollType type, gdouble value, t_sensors_dialog *ptr_sensorsdialog)
+{
+    t_sensors *sensors;
+    sensors = ptr_sensorsdialog->sensors;
+    g_assert (sensors!=NULL);
+
+    sensors->val_tachos_alpha = val_alpha = value; //gtk_scale_button_get_value(GTK_SCALE_BUTTON(ptr_widget));
+    DBG("new alpha value is %f.", val_alpha);
+
+    if (sensors->display_values_type==DISPLAY_TACHO)
+    {
+        /* refresh the panel content */
+        sensors_update_tacho_panel (sensors);
+    }
 }
 
 
@@ -2186,7 +2254,8 @@ add_font_settings_box (GtkWidget * vbox, t_sensors_dialog * sd)
 
     myFontLabel = gtk_label_new_with_mnemonic (_("F_ont:"));
     myFontSettingsBox = gtk_hbox_new (FALSE, BORDER);
-    myFontSettingsButton = gtk_font_button_new_with_font(font);
+    myFontSettingsButton = gtk_font_button_new();
+    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(myFontSettingsButton), font);
     gtk_font_button_set_use_font(GTK_FONT_BUTTON(myFontSettingsButton), TRUE);
 
     sd->fontSettings_Box = myFontSettingsBox;
@@ -2257,6 +2326,59 @@ add_smallspacings_box (GtkWidget * vbox, t_sensors_dialog * sd)
 }
 
 
+/* -------------------------------------------------------------------------- */
+static void
+add_tachos_appearance_boxes(GtkWidget * vbox, t_sensors_dialog * sd)
+{
+    GtkWidget *widget_hscale;
+    GtkWidget *widget_label;
+    //GtkWidget *widget_groupbox;
+    TRACE ("enters add_tachos_appearance_boxes");
+
+//widget_groupbox = xfce_groub_box ...
+
+    sd->alpha_slider_box = gtk_hbox_new(FALSE, INNER_BORDER);
+    widget_label = gtk_label_new(_("Tacho color alpha value:"));
+    gtk_widget_show (widget_label);
+    gtk_box_pack_start (GTK_BOX (sd->alpha_slider_box), widget_label, FALSE, TRUE, 0);
+    widget_hscale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0.0, 1.0, 0.01);
+    gtk_range_set_value(GTK_RANGE(widget_hscale), sd->sensors->val_tachos_alpha);
+    gtk_widget_show (widget_hscale);
+    g_signal_connect   (G_OBJECT (widget_hscale), "change-value",
+                        G_CALLBACK (tachos_alpha_changed_), sd );
+    gtk_box_pack_start (GTK_BOX (sd->alpha_slider_box), widget_hscale, TRUE, TRUE, 0);
+    gtk_widget_show (sd->alpha_slider_box);
+
+
+    sd->colorvalue_slider_box = gtk_hbox_new(FALSE, INNER_BORDER);
+    // The value from HSV color model
+    widget_label = gtk_label_new(_("Tacho color value:"));
+    gtk_widget_show (widget_label);
+    gtk_box_pack_start (GTK_BOX (sd->colorvalue_slider_box), widget_label, FALSE, TRUE, 0);
+    widget_hscale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0.0, 1.0, 0.01);
+    gtk_range_set_value(GTK_RANGE(widget_hscale), sd->sensors->val_tachos_color);
+    gtk_widget_show (widget_hscale);
+    g_signal_connect   (G_OBJECT (widget_hscale), "change-value",
+                        G_CALLBACK (tachos_colorvalue_changed_), sd );
+    gtk_box_pack_start (GTK_BOX (sd->colorvalue_slider_box), widget_hscale, TRUE, TRUE, 0);
+    gtk_widget_show (sd->colorvalue_slider_box);
+
+    gtk_box_pack_start (GTK_BOX (vbox), sd->alpha_slider_box, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), sd->colorvalue_slider_box, FALSE, TRUE, 0);
+
+    //gtk_box_pack_start (GTK_BOX (vbox), widget_groupbox, FALSE, TRUE, 0);
+
+    if (sd->sensors->display_values_type!=DISPLAY_TACHO)
+    {
+        gtk_widget_hide(sd->alpha_slider_box);
+        gtk_widget_hide(sd->colorvalue_slider_box);
+        //gtk_widget_hide(widget_groupbox);
+    }
+
+    TRACE ("leaves add_tachos_appearance_boxes");
+}
+
+
 /* -------------------------------------------------------------------------- */
 static void
 add_suppressmessage_box (GtkWidget * vbox, t_sensors_dialog * sd)
@@ -2363,13 +2485,14 @@ add_view_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 
     add_ui_style_box (_vbox, sd);
     add_labels_box (_vbox, sd);
+    add_cover_rows_box(_vbox, sd);
     add_str_fontsize_box (_vbox, sd);
     add_font_settings_box (_vbox, sd);
     add_lines_box (_vbox, sd);
-    add_cover_rows_box(_vbox, sd);
     add_colored_bars_box (_vbox, sd);
     add_units_box (_vbox, sd);
     add_smallspacings_box(_vbox, sd);
+    add_tachos_appearance_boxes(_vbox, sd);
 
     TRACE ("leaves add_view_frame");
 }
@@ -2563,6 +2686,30 @@ create_sensors_control (XfcePanelPlugin *plugin)
 }
 
 
+static void
+sensors_show_about(XfcePanelPlugin *plugin, t_sensors *ptr_sensorsstruct)
+{
+   GdkPixbuf *icon;
+   const gchar *auth[] = {"Fabian Nowak <timystery@xfce.org>",
+                          "Stefan Ott",
+                          NULL };
+   icon = xfce_panel_pixbuf_from_source("xfce-sensors", NULL, 32);
+   gtk_show_about_dialog(NULL,
+      "logo", icon,
+      "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
+      "version", PACKAGE_VERSION,
+      "program-name", PACKAGE_NAME,
+      "comments", _("Show sensor values from LM sensors, ACPI, hard disks, NVIDIA"),
+      "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-sensors-plugin",
+      "copyright", _("Copyright (c) 2004-2018\n"),
+      "authors", auth, NULL);
+  // TODO: add translators.
+
+   if(icon)
+      g_object_unref(G_OBJECT(icon));
+}
+
+
 /* -------------------------------------------------------------------------- */
 static void
 sensors_plugin_construct (XfcePanelPlugin *plugin)
@@ -2608,14 +2755,18 @@ sensors_plugin_construct (XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "free-data", G_CALLBACK (sensors_free), ptr_sensorsstruct);
 
     ptr_sensorsstruct->plugin_config_file = xfce_panel_plugin_save_location (plugin, TRUE);
-    g_signal_connect (plugin, "save", G_CALLBACK (sensors_write_config),
-                      ptr_sensorsstruct);
+    /* saving seens to cause problems when closing the panel on fast multi-core CPUs; writing when closing the config dialog should suffice */
+    /*g_signal_connect (plugin, "save", G_CALLBACK (sensors_write_config),
+                      ptr_sensorsstruct);*/
 
     xfce_panel_plugin_menu_show_configure (plugin);
 
     g_signal_connect (plugin, "configure-plugin",
                       G_CALLBACK (sensors_create_options), ptr_sensorsstruct);
 
+    xfce_panel_plugin_menu_show_about(plugin);
+    g_signal_connect (plugin, "about", G_CALLBACK (sensors_show_about), ptr_sensorsstruct);
+
     g_signal_connect (plugin, "size-changed", G_CALLBACK (sensors_set_size),
                          ptr_sensorsstruct);
 
